StationConfig

Struct StationConfig 

pub struct StationConfig { /* private fields */ }
Available on crate feature wifi only.
Station configuration for a Wi-Fi connection.

Implementations

Source

impl StationConfig

pub fn ssid(&self) -> Ssid

The SSID of the Wi-Fi network.

pub fn with_bssid(self, bssid: [u8; 6]) -> Self

Assign the given value to the bssid field.

pub fn with_bssid_none(self) -> Self

Set the value of bssid to None.

pub fn bssid(&self) -> Option<[u8; 6]>

The BSSID (MAC address) of the station.

pub fn with_auth_method(self, auth_method: AuthenticationMethod) -> Self

Assign the given value to the auth_method field.

pub fn auth_method(&self) -> AuthenticationMethod

The authentication method for the Wi-Fi connection.

pub fn with_password(self, password: String) -> Self

Assign the given value to the password field.

pub fn password(&self) -> &String

The password for the Wi-Fi connection.

pub fn with_channel(self, channel: u8) -> Self

Assign the given value to the channel field.

pub fn with_channel_none(self) -> Self

Set the value of channel to None.

pub fn channel(&self) -> Option<u8>

The Wi-Fi channel to connect to.

pub fn with_protocols(self, protocols: Protocols) -> Self

Assign the given value to the protocols field.

pub fn protocols(&self) -> Protocols

The set of protocols supported by the access point.

pub fn with_listen_interval(self, listen_interval: u16) -> Self

Available on crate feature unstable only.

Assign the given value to the listen_interval field.

pub fn listen_interval(&self) -> u16

Available on crate feature unstable only.

Interval for station to listen to beacon from access point.

The unit of listen interval is one beacon interval. For example, if beacon interval is 100 ms and listen interval is 3, the interval for station to listen to beacon is 300 ms

pub fn with_beacon_timeout(self, beacon_timeout: u16) -> Self

Available on crate feature unstable only.

Assign the given value to the beacon_timeout field.

pub fn beacon_timeout(&self) -> u16

Available on crate feature unstable only.

Time to disconnect from access point if no data is received.

Must be between 6 and 31.

pub fn with_failure_retry_cnt(self, failure_retry_cnt: u8) -> Self

Available on crate feature unstable only.

Assign the given value to the failure_retry_cnt field.

pub fn failure_retry_cnt(&self) -> u8

Available on crate feature unstable only.

Number of connection retries station will do before moving to next access point.

scan_method should be set as ScanMethod::AllChannels to use this config.

Note: Enabling this may cause connection time to increase in case the best access point doesn’t behave properly.

pub fn with_scan_method(self, scan_method: ScanMethod) -> Self

Available on crate feature unstable only.

Assign the given value to the scan_method field.

pub fn scan_method(&self) -> ScanMethod

Available on crate feature unstable only.

Scan method.

Source

impl StationConfig

pub fn with_ssid(self, ssid: impl Into<Ssid>) -> Self

Set the SSID of the access point.